<?php

class		ProductSale
{
	/*
	** Fill the `product_sale` SQL table with data from `order_detail`
	** @return bool True on success	  
	*/
	static public function fillProductSales()
	{
		$result = Db::getInstance()->ExecuteS('
		REPLACE INTO '._DB_PREFIX_.'product_sale
		(`id_product`, `quantity`, `nb_vente`, `date_upd`)
		VALUES (SELECT od.product_id, COUNT(od.product_id), SUM(od.product_quantity), NOW()
					FROM '._DB_PREFIX_.'order_detail od GROUP BY od.product_id)');
		return $result;
	}
	
	/*
	** Get number of actives products sold
	** @return int number of actives products listed in product_sales 	
	*/	
	static public function getNbSales()
	{
		$result = Db::getInstance()->getRow('
			SELECT COUNT(ps.`id_product`) AS nb
			FROM `'._DB_PREFIX_.'product_sale` ps
			LEFT JOIN `'._DB_PREFIX_.'product` p ON p.`id_product` = ps.`id_product`
			WHERE p.`active` = 1');
		return intval($result['nb']);
	}
	
	/*
	** Get required informations on best sales products
	**	
	** @param integer $id_lang Language id
	** @param integer $pageNumber Start from (optional)
	** @param integer $nbProducts Number of products to return (optional)
	** @return array from Product::getProductProperties
	*/
	static public function getBestSales($id_lang, $pageNumber = 0, $nbProducts = 10)
	{
	 	global	$link, $cookie;

		if (get_class($link) != 'Link')
			die (Tools::displayError());
	 	
		if ($pageNumber < 0) $pageNumber = 0;
		if ($nbProducts < 1) $nbProducts = 10;
			
		$result = Db::getInstance()->ExecuteS('
		SELECT p.*, pl.`link_rewrite`, pl.`name`, i.`id_image`, il.`legend`, ps.`quantity` AS sales, t.`rate`, pl.`meta_keywords`, pl.`meta_title`, pl.`meta_description`
		FROM `'._DB_PREFIX_.'product_sale` ps 
		LEFT JOIN `'._DB_PREFIX_.'product` p ON ps.`id_product` = p.`id_product`
		LEFT JOIN `'._DB_PREFIX_.'product_lang` pl ON (p.`id_product` = pl.`id_product` AND pl.`id_lang` = '.intval($id_lang).')
		LEFT JOIN `'._DB_PREFIX_.'image` i ON (i.`id_product` = p.`id_product` AND i.`cover` = 1)
		LEFT JOIN `'._DB_PREFIX_.'image_lang` il ON (i.`id_image` = il.`id_image` AND il.`id_lang` = '.intval($id_lang).')
		LEFT JOIN `'._DB_PREFIX_.'tax` t ON (t.`id_tax` = p.`id_tax`)
		WHERE p.`active` = 1
		GROUP BY p.`id_product`
		ORDER BY sales DESC
		LIMIT '.intval($pageNumber * $nbProducts).', '.intval($nbProducts));
		if (!$result)
			return false;
		
		return Product::getProductsProperties($id_lang, $result);
	}	
	
	/*
	** Get required informations on best sales products
	**				
	** @param integer $id_lang Language id
	** @param integer $pageNumber Start from (optional)
	** @param integer $nbProducts Number of products to return (optional)
	** @return array keys : id_product, link_rewrite, name, id_image, legend, sales, ean13 , link
	*/
	static public function getBestSalesLight($id_lang, $pageNumber = 0, $nbProducts = 10)
	{
	 	global	$link, $cookie;
		if (get_class($link) != 'Link')
			die (Tools::displayError());
	 	
		if ($pageNumber < 0) $pageNumber = 0;
		if ($nbProducts < 1) $nbProducts = 10;
		
		$result = Db::getInstance()->ExecuteS('
		SELECT p.id_product, pl.`link_rewrite`, pl.`name`, i.`id_image`, il.`legend`, ps.`quantity` AS sales, p.`ean13`
		FROM `'._DB_PREFIX_.'product_sale` ps 
		LEFT JOIN `'._DB_PREFIX_.'product` p ON ps.`id_product` = p.`id_product`
		LEFT JOIN `'._DB_PREFIX_.'product_lang` pl ON (p.`id_product` = pl.`id_product` AND pl.`id_lang` = '.intval($id_lang).')
		LEFT JOIN `'._DB_PREFIX_.'image` i ON (i.`id_product` = p.`id_product` AND i.`cover` = 1)
		LEFT JOIN `'._DB_PREFIX_.'image_lang` il ON (i.`id_image` = il.`id_image` AND il.`id_lang` = '.intval($id_lang).')
		WHERE p.`active` = 1
		GROUP BY p.`id_product`
		ORDER BY sales DESC
		LIMIT '.intval($pageNumber * $nbProducts).', '.intval($nbProducts));
		if (!$result)
			return false;
		
		foreach ($result AS &$row)
		{
		 	$row['link'] = $link->getProductLink($row['id_product'], $row['link_rewrite'], $row['ean13']);
		 	$row['id_image'] = Product::defineProductImage($row);
		}
		return $result;
	}

	static public function addProductSale($product_id, $qty = 1)
	{
		Db::getInstance()->Execute('INSERT INTO '._DB_PREFIX_.'product_sale
										(`id_product`, `quantity`, `nb_vente`, `date_upd`)
										VALUES ('.intval($product_id).', '.intval($qty).', 1, NOW())
										ON DUPLICATE KEY UPDATE `quantity` = `quantity` + '.intval($qty).', `nb_vente` = `nb_vente` + 1, `date_upd` = NOW()');
	}
}	
?>
